@@ -3,15 +3,10 @@
 
 #include <QSqlTableModel>
 
-class Session;
-
 class DailymotionAccountsListModel : public QSqlTableModel
 {
     Q_OBJECT
 
-    Q_PROPERTY(Session* session
-               READ session
-               WRITE setSession)
     Q_PROPERTY(int count
                READ rowCount
                NOTIFY countChanged)
@@ -22,15 +17,12 @@ public:
         UsernameRole,
         AccessTokenRole,
         RefreshTokenRole,
-        CookiesRole,
         ActiveRole
     };
 
 public:
-    explicit DailymotionAccountsListModel(Session *session = 0, QObject *parent = 0);
+    explicit DailymotionAccountsListModel(QObject *parent = 0);
     ~DailymotionAccountsListModel();
-    inline Session* session() const { return m_session; }
-    void setSession(Session *session);
     QVariant data(const QModelIndex &idx, int role) const;
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
 
@@ -46,12 +38,8 @@ signals:
     void accountSelected(const QString &user, const QString &token, const QString &refresh);
     void accountAdded(const QString &user, const QString &token, const QString &refresh);
     void accountDeleted();
-    void gotCookies(const QByteArray &cookieString);
     void error(const QString &errorString);
     void countChanged(int count);
-
-private:
-    Session *m_session;
 };
 
 #endif // DAILYMOTIONACCOUNTSLISTMODEL_H
