@@ -5,15 +5,10 @@
 #include <QAbstractListModel>
 #include <QSharedPointer>
 
-class Session;
-
 class DailymotionUserPlaylistListModel : public QAbstractListModel
 {
     Q_OBJECT
 
-    Q_PROPERTY(Session* session
-               READ session
-               WRITE setSession)
     Q_PROPERTY(int count
                READ rowCount
                NOTIFY countChanged)
@@ -30,15 +25,15 @@ public:
     };
 
 public:
-    explicit DailymotionUserPlaylistListModel(Session *session = 0, QObject *parent = 0);
+    explicit DailymotionUserPlaylistListModel(QObject *parent = 0);
     ~DailymotionUserPlaylistListModel() {}
-    inline Session* session() const { return m_session; }
-    void setSession(Session *session);
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
     QSharedPointer<PlaylistItem> get(int row) const;
+#ifdef QML_USER_INTERFACE
     Q_INVOKABLE PlaylistItem* getFromQML(int row) const;
+#endif
 
 private slots:
     void onPlaylistAdded(int row);
@@ -47,9 +42,6 @@ private slots:
 
 signals:
     void countChanged(int count);
-
-private:
-    Session *m_session;
 };
 
 #endif // DAILYMOTIONUSERPLAYLISTLISTMODEL_H
