@@ -2,7 +2,7 @@
 #define ENUMS_H
 
 #include <QObject>
-#include <QNetworkProxy>
+#include <QtNetwork/QNetworkProxy>
 
 class Services : public QObject
 {
