@@ -53,6 +53,9 @@ Settings::Settings(QObject *parent) :
   #else
     m_cuteTubePlayerEnabled(false)
   #endif
+  #ifdef GRABBER_PLUGIN
+  ,m_updatePlugin(false)
+  #endif
 {
     if (!settingsInstance) {
         settingsInstance = this;
@@ -158,6 +161,9 @@ void Settings::restoreSettings() {
     this->setNetworkProxyUser(this->value("networkProxyUser", QString()).toString());
     this->setNetworkProxyPassword(QString(QByteArray::fromBase64(this->value("networkProxyPassword", QByteArray()).toByteArray())));
     this->setNetworkProxy();
+#ifdef GRABBER_PLUGIN
+    this->setUpdatePluginOnStartup(this->value("updatePluginOnStartup", false).toBool());
+#endif
     this->endGroup();
 }
 
@@ -228,6 +234,9 @@ void Settings::saveSettings() {
     this->setValue("networkProxyPort", this->networkProxyPort());
     this->setValue("networkProxyUser", this->networkProxyUser());
     this->setValue("networkProxyPassword", this->networkProxyPassword().toUtf8().toBase64());
+#ifdef GRABBER_PLUGIN
+    this->setValue("updatePluginOnStartup", this->updatePluginOnStartup());
+#endif
     this->endGroup();
 }
 
@@ -835,3 +844,12 @@ bool Settings::eventFeedInstalled() const {
 void Settings::setCuteTubePlayerEnabled(bool enabled) {
     m_cuteTubePlayerEnabled = enabled;
 }
+
+#ifdef GRABBER_PLUGIN
+void Settings::setUpdatePluginOnStartup(bool update) {
+    if (update != this->updatePluginOnStartup()) {
+        m_updatePlugin = update;
+        emit updatePluginOnStartupChanged(update);
+    }
+}
+#endif
