@@ -9,6 +9,7 @@
 
 class QNetworkAccessManager;
 class QNetworkReply;
+class ExtractorPlugin;
 
 typedef struct {
     Videos::VideoFormat format;
@@ -61,6 +62,7 @@ private slots:
     void checkVimeoVideoFormats();
 
 private:
+    void loadExtractorPlugin();
     void setBusy(bool isBusy, const QString &message = QString(), int numberOfOperations = 1);
     void setCancelled(bool cancelled) { m_cancelled = cancelled; }
     QString decryptYouTubeSignature(const QString &s);
@@ -76,6 +78,7 @@ signals:
 
 private:
     QNetworkAccessManager *m_nam;
+    ExtractorPlugin *m_extractor;
     QList<VideoFormat> m_youtubeFormats;
     QList<VideoFormat> m_dailymotionFormats;
     QList<VideoFormat> m_vimeoFormats;
