@@ -14,12 +14,15 @@
 
 using namespace QtOAuth;
 
+Vimeo* vimeoInstance = 0;
+
+const QString CLIENT_ID("b73846eb250c788a08bda2458be6ae9aebfda98e");
+const QString CLIENT_SECRET("6d6a7f4b5f013efe183f12d6e09be31051eb5eed");
+const QString REDIRECT_URI("https://sites.google.com/site/marxodian/home/cutetube");
+
 Vimeo::Vimeo(QObject *parent) :
     QObject(parent),
     m_nam(0),
-    m_clientId("b73846eb250c788a08bda2458be6ae9aebfda98e"),
-    m_clientSecret("6d6a7f4b5f013efe183f12d6e09be31051eb5eed"),
-    m_redirectUri("https://sites.google.com/site/marxodian/home/cutetube"),
     m_safeSearch(false),
     m_actionsProcessed(0),
     m_albumCache(new QList< QSharedPointer<PlaylistItem> >),
@@ -28,8 +31,13 @@ Vimeo::Vimeo(QObject *parent) :
     m_albumCacheLoaded(false),
     m_groupCacheLoaded(false),
     m_subscriptionCacheLoaded(false),
-    m_busy(false)
+    m_busy(false),
+    m_cancelled(false)
 {
+    if (!vimeoInstance) {
+        vimeoInstance = this;
+    }
+
     m_queryOrders[Queries::Relevance] = "relevant";
     m_queryOrders[Queries::Date] = "newest";
     m_queryOrders[Queries::Views] = "most_played";
@@ -40,14 +48,19 @@ Vimeo::~Vimeo() {
     this->clearCache();
 }
 
+Vimeo* Vimeo::instance() {
+    return vimeoInstance;
+}
+
 void Vimeo::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
     if (isBusy != this->busy()) {
         m_busy = isBusy;
 
         if (isBusy) {
+            this->setCancelled(false);
             emit busy(message, numberOfOperations);
         }
-        else {
+        else if (!this->cancelled()) {
             emit busyProgressChanged(numberOfOperations);
         }
 
@@ -55,18 +68,29 @@ void Vimeo::setBusy(bool isBusy, const QString &message, int numberOfOperations)
     }
 }
 
-QNetworkReply* Vimeo::createReply(QString feed, int offset) {
-    QUrl url(feed);
+void Vimeo::cancelCurrentOperation() {
+    this->setCancelled(true);
+    this->setBusy(false);
+    this->disconnect(this, SIGNAL(postSuccessful(QString)), this, 0);
+    this->disconnect(this, SIGNAL(postFailed(QString)), this, 0);
+#ifdef QML_USER_INTERFACE
+    this->disconnect(this, SIGNAL(gotVideo(VideoItem*)), 0, 0);
+#else
+    this->disconnect(this, SIGNAL(gotVideo(QSharedPointer<VideoItem>)), 0, 0);
+#endif
+    emit currentOperationCancelled();
+}
 
+QNetworkReply* Vimeo::createReply(QUrl feed, int offset) {
     if (offset) {
-        url.addQueryItem("page", QString::number(offset));
+        feed.addQueryItem("page", QString::number(offset));
     }
 
-    qDebug() << url;
+    qDebug() << feed;
 
-    QNetworkRequest request(url);
+    QNetworkRequest request(feed);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
-    request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
+    request.setRawHeader("Authorization", this->getOAuthHeader("GET", feed, QMap<QString, QString>()));
 
     return this->networkAccessManager()->get(request);
 }
@@ -93,8 +117,8 @@ QNetworkReply* Vimeo::createSearchReply(const QString &query, int offset, int or
 }
 
 QByteArray Vimeo::getOAuthHeader(const QString &method, const QUrl &url, QMap<QString, QString> params) {
-    params.insert("oauth_consumer_key", m_clientId);
-    params.insert("oauth_consumer_secret", m_clientSecret);
+    params.insert("oauth_consumer_key", CLIENT_ID);
+    params.insert("oauth_consumer_secret", CLIENT_SECRET);
 
     if (this->userSignedIn()) {
         params.insert("oauth_token", this->accessToken());
@@ -107,7 +131,7 @@ QByteArray Vimeo::getOAuthHeader(const QString &method, const QUrl &url, QMap<QS
 void Vimeo::getAuthUrl() {
     QUrl url("https://vimeo.com/oauth/request_token");
     QMap<QString, QString> params;
-    params.insert("oauth_callback", m_redirectUri);
+    params.insert("oauth_callback", REDIRECT_URI);
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, params));
@@ -116,7 +140,7 @@ void Vimeo::getAuthUrl() {
 }
 
 void Vimeo::checkAuthUrl() {
-    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
@@ -161,12 +185,13 @@ void Vimeo::signIn(const QString &displayName, const QUrl &response) {
         request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, params));
         QNetworkReply *reply = this->networkAccessManager()->get(request);
         this->connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedIn()));
+        this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
     }
 }
 
 void Vimeo::checkIfSignedIn() {
     this->setBusy(false);
-    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
@@ -221,10 +246,11 @@ void Vimeo::postRequest(const QUrl &url) {
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply* reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(postFinished()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
 }
 
 void Vimeo::postFinished() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
@@ -266,7 +292,7 @@ void Vimeo::getAlbums(int offset) {
 }
 
 void Vimeo::addAlbums() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
@@ -286,14 +312,13 @@ void Vimeo::addAlbums() {
             m_albumCache->append(QSharedPointer<PlaylistItem>(album));
         }
 
-        this->setAlbumsLoaded(true);
-
         QDomElement statNode = responseNode.firstChildElement("albums");
 
         if ((statNode.attribute("total").toInt() > m_albumCache->size()) && (!entries.isEmpty())) {
             this->getAlbums(statNode.attribute("page").toInt() + 1);
         }
         else {
+            this->setAlbumsLoaded(true);
             emit allAlbumsLoaded();
         }
     }
@@ -306,6 +331,9 @@ void Vimeo::addAlbums() {
         else {
             emit error(tr("Unable to retrieve albums"));
         }
+
+        this->setAlbumsLoaded(true);
+        emit allAlbumsLoaded();
     }
 
     reply->deleteLater();
@@ -377,7 +405,7 @@ void Vimeo::getGroups(int offset) {
 }
 
 void Vimeo::addGroups() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
@@ -394,18 +422,16 @@ void Vimeo::addGroups() {
         for (int i = 0; i < entries.size(); i++) {
             GroupItem *group = new GroupItem;
             group->loadVimeoGroup(entries.at(i).toElement());
-            this->connect(this, SIGNAL(groupMembershipChanged(QString,bool)), group, SLOT(onMembershipChanged(QString,bool)));
             m_groupCache->append(QSharedPointer<GroupItem>(group));
         }
 
-        this->setGroupsLoaded(true);
-
         QDomElement statNode = responseNode.firstChildElement("groups");
 
         if ((statNode.attribute("total").toInt() > m_groupCache->size()) && (!entries.isEmpty())) {
             this->getGroups(statNode.attribute("page").toInt() + 1);
         }
         else {
+            this->setGroupsLoaded(true);
             emit allGroupsLoaded();
         }
     }
@@ -418,6 +444,9 @@ void Vimeo::addGroups() {
         else {
             emit error(tr("Unable to retrieve groups"));
         }
+
+        this->setGroupsLoaded(true);
+        emit allGroupsLoaded();
     }
 
     reply->deleteLater();
@@ -427,7 +456,6 @@ void Vimeo::addNewGroupToCache(QSharedPointer<GroupItem> group) {
     m_groupCache->insert(0, group);
     emit groupAddedToCache(0);
     emit groupMembershipChanged(group.data()->id(), true);
-    this->connect(this, SIGNAL(groupMembershipChanged(QString,bool)), group.data(), SLOT(onMembershipChanged(QString,bool)));
 }
 
 QSharedPointer<GroupItem> Vimeo::removeGroupFromCache(const QString &id) {
@@ -461,7 +489,7 @@ void Vimeo::getSubscriptions(int offset) {
 }
 
 void Vimeo::addSubscriptions() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
@@ -478,18 +506,16 @@ void Vimeo::addSubscriptions() {
         for (int i = 0; i < entries.size(); i++) {
             UserItem *user = new UserItem;
             user->loadVimeoContact(entries.at(i).toElement(), true);
-            this->connect(this, SIGNAL(subscriptionChanged(QString,bool)), user, SLOT(onSubscriptionChanged(QString,bool)));
             m_subscriptionCache->append(QSharedPointer<UserItem>(user));
         }
 
-        this->setSubscriptionsLoaded(true);
-
         QDomElement statNode = responseNode.firstChildElement("contacts");
 
         if ((statNode.attribute("total").toInt() > m_subscriptionCache->size()) && (!entries.isEmpty())) {
             this->getSubscriptions(statNode.attribute("page").toInt() + 1);
         }
         else {
+            this->setSubscriptionsLoaded(true);
             emit allSubscriptionsLoaded();
         }
     }
@@ -502,24 +528,18 @@ void Vimeo::addSubscriptions() {
         else {
             emit error(tr("Unable to retrieve subscriptions"));
         }
+
+        this->setSubscriptionsLoaded(true);
+        emit allSubscriptionsLoaded();
     }
 
     reply->deleteLater();
 }
 
 void Vimeo::addNewSubscriptionToCache(QSharedPointer<UserItem> user) {
-    int i = 0;
-    bool found = false;
-
-    while ((!found) && (i < m_subscriptionCache->size())) {
-        found = (m_subscriptionCache->at(i).data()->username() > user.data()->username());
-        i++;
-    }
-
-    m_subscriptionCache->insert(i - 1, user);
-    emit subscriptionAddedToCache(i - 1);
+    m_subscriptionCache->insert(0, user);
+    emit subscriptionAddedToCache(0);
     emit subscriptionChanged(user.data()->id(), true);
-    this->connect(this, SIGNAL(subscriptionChanged(QString,bool,QString)), user.data(), SLOT(onSubscriptionChanged(QString,bool,QString)));
 }
 
 QSharedPointer<UserItem> Vimeo::removeSubscriptionFromCache(const QString &id) {
@@ -553,17 +573,22 @@ void Vimeo::getFullVideo(QString id) {
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkFullVideo()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
 }
 
 void Vimeo::checkFullVideo() {
     this->setBusy(false);
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
         return;
     }
 
+    if (this->cancelled()) {
+        return;
+    }
+
     QDomDocument doc;
     doc.setContent(reply->readAll());
     QDomElement responseNode = doc.firstChildElement("rsp");
@@ -573,7 +598,6 @@ void Vimeo::checkFullVideo() {
         doc.setContent(reply->readAll());
         VideoItem *video = new VideoItem;
         video->loadVimeoVideo(responseNode.firstChildElement("video"));
-        this->connect(this, SIGNAL(likeChanged(QString,bool)), video, SLOT(onFavouriteChanged(QString,bool)));
 #ifdef QML_USER_INTERFACE
         QDeclarativeEngine::setObjectOwnership(video, QDeclarativeEngine::JavaScriptOwnership);
         emit gotVideo(video);
@@ -590,8 +614,11 @@ void Vimeo::checkFullVideo() {
         else {
             emit error(tr("Unable to retrieve video"));
         }
-
+#ifdef QML_USER_INTERFACE
+        this->disconnect(this, SIGNAL(gotVideo(VideoItem*)), 0, 0);
+#else
         this->disconnect(this, SIGNAL(gotVideo(QSharedPointer<VideoItem>)), 0, 0);
+#endif
     }
 
     reply->deleteLater();
@@ -608,7 +635,7 @@ void Vimeo::getCurrentUserProfile() {
 }
 
 void Vimeo::checkCurrentUserProfile() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
@@ -660,7 +687,7 @@ void Vimeo::getUserProfile(const QString &id) {
 }
 
 void Vimeo::checkUserProfile() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
@@ -674,8 +701,6 @@ void Vimeo::checkUserProfile() {
     if (responseNode.attribute("stat") == "ok") {
         UserItem *user = new UserItem;
         user->loadVimeoProfile(responseNode.firstChildElement("person"));
-        this->connect(this, SIGNAL(subscriptionChanged(QString,bool)), user, SLOT(onSubscriptionChanged(QString,bool)));
-
 #ifdef QML_USER_INTERFACE
         QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
         emit gotUser(user);
@@ -721,21 +746,23 @@ void Vimeo::deleteFromUploads() {
 }
 
 void Vimeo::onVideoDeleted() {
-    m_actionsProcessed++;
-    emit busyProgressChanged(m_actionsProcessed);
-
     if (!m_actionIdList.isEmpty()) {
         emit deletedFromUploads(m_actionIdList.takeFirst());
     }
-    if (!m_actionIdList.isEmpty()) {
-        this->deleteFromUploads();
-    }
-    else {
-        this->setBusy(false);
-        emit alert(tr("Video(s) deleted from uploads"));
+    if (!this->cancelled()) {
+        m_actionsProcessed++;
+        emit busyProgressChanged(m_actionsProcessed);
 
-        this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onVideoDeleted()));
-        this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        if (!m_actionIdList.isEmpty()) {
+            this->deleteFromUploads();
+        }
+        else {
+            this->setBusy(false);
+            emit alert(tr("Video(s) deleted from uploads"));
+
+            this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onVideoDeleted()));
+            this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        }
     }
 }
 
@@ -766,21 +793,23 @@ void Vimeo::addToLikes() {
 void Vimeo::onAddedToLikes(const QString &response) {
     Q_UNUSED(response)
 
-    m_actionsProcessed++;
-    emit busyProgressChanged(m_actionsProcessed);
-
     if (!m_actionIdList.isEmpty()) {
         emit likeChanged(m_actionIdList.takeFirst(), true);
     }
-    if (!m_actionIdList.isEmpty()) {
-        this->addToLikes();
-    }
-    else {
-        this->setBusy(false);
-        emit alert(tr("Video(s) added to likes"));
+    if (!this->cancelled()) {
+        m_actionsProcessed++;
+        emit busyProgressChanged(m_actionsProcessed);
 
-        this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAddedToLikes(QString)));
-        this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        if (!m_actionIdList.isEmpty()) {
+            this->addToLikes();
+        }
+        else {
+            this->setBusy(false);
+            emit alert(tr("Video(s) added to likes"));
+
+            this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAddedToLikes(QString)));
+            this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        }
     }
 }
 
@@ -808,22 +837,24 @@ void Vimeo::deleteFromLikes() {
     }
 }
 
-void Vimeo::onDeletedFromLikes() {
-    m_actionsProcessed++;
-    emit busyProgressChanged(m_actionsProcessed);
-
+void Vimeo::onDeletedFromLikes() {    
     if (!m_actionIdList.isEmpty()) {
         emit likeChanged(m_actionIdList.takeFirst(), false);
     }
-    if (!m_actionIdList.isEmpty()) {
-        this->deleteFromLikes();
-    }
-    else {
-        this->setBusy(false);
-        emit alert(tr("Video(s) deleted from likes"));
+    if (!this->cancelled()) {
+        m_actionsProcessed++;
+        emit busyProgressChanged(m_actionsProcessed);
 
-        this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onDeletedFromLikes()));
-        this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        if (!m_actionIdList.isEmpty()) {
+            this->deleteFromLikes();
+        }
+        else {
+            this->setBusy(false);
+            emit alert(tr("Video(s) deleted from likes"));
+
+            this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onDeletedFromLikes()));
+            this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        }
     }
 }
 
@@ -856,24 +887,26 @@ void Vimeo::addToAlbum() {
 void Vimeo::onAddedToAlbum(const QString &response) {
     Q_UNUSED(response)
 
-    m_actionsProcessed++;
-    emit busyProgressChanged(m_actionsProcessed);
-
     if (this->albumsLoaded()) {
         this->updateAlbumVideoCount(m_actionId, 1);
     }
     if (!m_actionIdList.isEmpty()) {
         emit addedToAlbum(m_actionIdList.takeFirst(), m_actionId);
     }
-    if (!m_actionIdList.isEmpty()) {
-        this->addToAlbum();
-    }
-    else {
-        this->setBusy(false);
-        emit alert(tr("Video(s) added to album"));
+    if (!this->cancelled()) {
+        m_actionsProcessed++;
+        emit busyProgressChanged(m_actionsProcessed);
 
-        this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAddedToAlbum(QString)));
-        this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        if (!m_actionIdList.isEmpty()) {
+            this->addToAlbum();
+        }
+        else {
+            this->setBusy(false);
+            emit alert(tr("Video(s) added to album"));
+
+            this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAddedToAlbum(QString)));
+            this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        }
     }
 }
 
@@ -903,24 +936,26 @@ void Vimeo::deleteFromAlbum() {
 }
 
 void Vimeo::onDeletedFromAlbum() {
-    m_actionsProcessed++;
-    emit busyProgressChanged(m_actionsProcessed);
-
     if (this->albumsLoaded()) {
         this->updateAlbumVideoCount(m_actionId, -1);
     }
     if (!m_actionIdList.isEmpty()) {
         emit deletedFromAlbum(m_actionIdList.takeFirst(), m_actionId);
     }
-    if (!m_actionIdList.isEmpty()) {
-        this->deleteFromAlbum();
-    }
-    else {
-        this->setBusy(false);
-        emit alert(tr("Video(s) deleted from album"));
+    if (!this->cancelled()) {
+        m_actionsProcessed++;
+        emit busyProgressChanged(m_actionsProcessed);
 
-        this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onDeletedFromAlbum()));
-        this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        if (!m_actionIdList.isEmpty()) {
+            this->deleteFromAlbum();
+        }
+        else {
+            this->setBusy(false);
+            emit alert(tr("Video(s) deleted from album"));
+
+            this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onDeletedFromAlbum()));
+            this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        }
     }
 }
 
@@ -950,21 +985,23 @@ void Vimeo::addToWatchLaterAlbum() {
 void Vimeo::onAddedToWatchLaterAlbum(const QString &response) {
     Q_UNUSED(response)
 
-    m_actionsProcessed++;
-    emit busyProgressChanged(m_actionsProcessed);
-
     if (!m_actionIdList.isEmpty()) {
         emit addedToWatchLaterAlbum(m_actionIdList.takeFirst());
     }
-    if (!m_actionIdList.isEmpty()) {
-        this->addToWatchLaterAlbum();
-    }
-    else {
-        this->setBusy(false);
-        emit alert(tr("Video(s) added to 'Watch Later' album"));
+    if (!this->cancelled()) {
+        m_actionsProcessed++;
+        emit busyProgressChanged(m_actionsProcessed);
 
-        this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAddedToWatchLaterAlbum(QString)));
-        this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        if (!m_actionIdList.isEmpty()) {
+            this->addToWatchLaterAlbum();
+        }
+        else {
+            this->setBusy(false);
+            emit alert(tr("Video(s) added to 'Watch Later' album"));
+
+            this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAddedToWatchLaterAlbum(QString)));
+            this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        }
     }
 }
 
@@ -991,22 +1028,24 @@ void Vimeo::deleteFromWatchLaterAlbum() {
     }
 }
 
-void Vimeo::onDeletedFromWatchLaterAlbum() {
-    m_actionsProcessed++;
-    emit busyProgressChanged(m_actionsProcessed);
-
+void Vimeo::onDeletedFromWatchLaterAlbum() {    
     if (!m_actionIdList.isEmpty()) {
         emit deletedFromWatchLaterAlbum(m_actionIdList.takeFirst());
     }
-    if (!m_actionIdList.isEmpty()) {
-        this->deleteFromWatchLaterAlbum();
-    }
-    else {
-        this->setBusy(false);
-        emit alert(tr("Video(s) deleted from 'Watch Later' album"));
+    if (!this->cancelled()) {
+        m_actionsProcessed++;
+        emit busyProgressChanged(m_actionsProcessed);
 
-        this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onDeletedFromWatchLaterAlbum()));
-        this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        if (!m_actionIdList.isEmpty()) {
+            this->deleteFromWatchLaterAlbum();
+        }
+        else {
+            this->setBusy(false);
+            emit alert(tr("Video(s) deleted from 'Watch Later' album"));
+
+            this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onDeletedFromWatchLaterAlbum()));
+            this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
+        }
     }
 }
 
@@ -1073,7 +1112,7 @@ void Vimeo::getAlbumForCache() {
 }
 
 void Vimeo::checkCacheAlbum() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
@@ -1164,7 +1203,7 @@ void Vimeo::getGroupForCache(const QString &id) {
 }
 
 void Vimeo::checkCacheGroup() {
-    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
@@ -1227,9 +1266,8 @@ void Vimeo::subscribe(const QString &userId) {
 
 void Vimeo::subscribe() {
     QUrl url(VIMEO_BASE_URL);
-    url.addQueryItem("method", "vimeo.people.addSubscription");
+    url.addQueryItem("method", "vimeo.people.addContact");
     url.addQueryItem("user_id", m_actionId);
-    url.addQueryItem("types", "uploads");
     this->postRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onSubscribed(QString)));
     this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onUserActionError(QString)));
@@ -1242,7 +1280,8 @@ void Vimeo::onSubscribed(const QString &response) {
         this->getSubscriptionForCache(m_actionId);
     }
     else {
-        emit alert(tr("You have subscribed to this person"));
+        emit subscriptionChanged(m_actionId, true);
+        emit alert(tr("You have subscribed to this channel"));
     }
 
     this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onSubscribed(QString)));
@@ -1261,7 +1300,7 @@ void Vimeo::getSubscriptionForCache(const QString &id) {
 }
 
 void Vimeo::checkCacheSubscription() {
-    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error("Network error");
@@ -1299,7 +1338,7 @@ void Vimeo::unsubscribe(const QString &userId) {
 
 void Vimeo::unsubscribe() {
     QUrl url(VIMEO_BASE_URL);
-    url.addQueryItem("method", "vimeo.people.removeSubscription");
+    url.addQueryItem("method", "vimeo.people.removeContact");
     url.addQueryItem("user_id", m_actionId);
     this->postRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onUnsubscribed()));
@@ -1314,11 +1353,13 @@ void Vimeo::onUnsubscribed() {
             emit alert(tr("You have unsubscribed to '%1'").arg(user.data()->channelName()));
         }
         else {
-            emit alert(tr("You have unsubscribed to this person"));
+            emit subscriptionChanged(m_actionId, false);
+            emit alert(tr("You have unsubscribed to this channel"));
         }
     }
     else {
-        emit alert(tr("You have unsubscribed to this person"));
+        emit subscriptionChanged(m_actionId, false);
+        emit alert(tr("You have unsubscribed to this channel"));
     }
 
     this->disconnect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onUnsubscribed()));
@@ -1378,7 +1419,7 @@ void Vimeo::getAddedComment(const QString &videoId) {
 }
 
 void Vimeo::checkAddedComment() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(tr("Network error"));
@@ -1444,3 +1485,52 @@ void Vimeo::onCommentActionError(const QString &errorString) {
     this->disconnect(this, SIGNAL(postFailed(QString)), this, SLOT(onCommentActionError(QString)));
     this->disconnect(this, SIGNAL(postSuccessful(QString)), this, 0);
 }
+
+void Vimeo::getVideosFromIds(QStringList ids) {
+    m_actionIdList = ids;
+
+    if (!m_actionIdList.isEmpty()) {
+        this->setBusy(true, QString(), 0);
+        this->getVideoFromId(m_actionIdList.takeFirst());
+    }
+}
+
+void Vimeo::getVideoFromId(const QString &id) {
+    QUrl url(VIMEO_BASE_URL);
+    url.addQueryItem("method", "vimeo.videos.getInfo");
+    url.addQueryItem("video_id", id);
+    QNetworkRequest request(url);
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
+    QNetworkReply *reply = this->networkAccessManager()->get(request);
+    this->connect(reply, SIGNAL(finished()), this, SLOT(checkVideoFromId()));
+}
+
+void Vimeo::checkVideoFromId() {
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        emit error(tr("Network error"));
+        return;
+    }
+
+    QDomDocument doc;
+    doc.setContent(reply->readAll());
+    QDomElement responseNode = doc.firstChildElement("rsp");
+
+    if (responseNode.attribute("stat") == "ok") {
+        QDomDocument doc;
+        doc.setContent(reply->readAll());
+        VideoItem *video = new VideoItem;
+        video->loadVimeoVideo(responseNode.firstChildElement("video"));
+        emit gotVideosFromIds(QList< QSharedPointer<VideoItem> >() << QSharedPointer<VideoItem>(video));
+    }
+    if (!m_actionIdList.isEmpty()) {
+        this->getVideoFromId(m_actionIdList.takeFirst());
+    }
+    else {
+        this->setBusy(false);
+    }
+
+    reply->deleteLater();
+}
