@@ -10,6 +10,7 @@
 #include <QAction>
 #include <QLabel>
 #include <QGridLayout>
+#include <QMaemo5Style>
 
 DailymotionVideoCommentsTab::DailymotionVideoCommentsTab(QSharedPointer<VideoItem> video, QWidget *parent) :
     AbstractTab(parent),
@@ -17,7 +18,7 @@ DailymotionVideoCommentsTab::DailymotionVideoCommentsTab(QSharedPointer<VideoIte
     m_model(new DailymotionCommentListModel(this)),
     m_listView(new ListView(this)),
     m_commentAction(new QAction(tr("Add comment"), this)),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No comments found")), this)),
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No comments found")), this)),
     m_grid(new QGridLayout(this))
 {
     this->addAction(m_commentAction);
