@@ -6,7 +6,6 @@
 #include <QVariantMap>
 
 class DailymotionVideoListModel;
-class Session;
 class ListView;
 class QMaemo5EditBar;
 class QPushButton;
@@ -17,7 +16,7 @@ class DailymotionVideoSelectionWindow : public QWidget
 {
     Q_OBJECT
 public:
-    explicit DailymotionVideoSelectionWindow(Session *session, DailymotionVideoListModel *model, const QString &text, const char* slot, QWidget *parent);
+    explicit DailymotionVideoSelectionWindow(DailymotionVideoListModel *model, const QString &text, const char* slot, QWidget *parent);
     ~DailymotionVideoSelectionWindow();
     void positionAtIndex(const QModelIndex &index);
 
@@ -39,7 +38,6 @@ signals:
     void accepted();
 
 private:
-    Session *m_session;
     DailymotionVideoListModel *m_model;
     ListView *m_listView;
     QMaemo5EditBar *m_editBar;
