@@ -17,13 +17,13 @@ void VideoPlayerButton::paintEvent(QPaintEvent *event) {
 
     switch (m_role) {
     case Previous:
-        painter.drawImage(this->rect(), this->isDown() ? QImage("/etc/hildon/theme/mediaplayer/BackPressed.png") : QImage("/etc/hildon/theme/mediaplayer/Back.png"));
+        painter.drawImage(3, 3, this->isDown() ? QImage("/etc/hildon/theme/mediaplayer/BackPressed.png") : QImage("/etc/hildon/theme/mediaplayer/Back.png"));
         break;
     case Next:
-        painter.drawImage(this->rect(), this->isDown() ? QImage("/etc/hildon/theme/mediaplayer/ForwardPressed.png") : QImage("/etc/hildon/theme/mediaplayer/Forward.png"));
+        painter.drawImage(3, 3, this->isDown() ? QImage("/etc/hildon/theme/mediaplayer/ForwardPressed.png") : QImage("/etc/hildon/theme/mediaplayer/Forward.png"));
         break;
     default:
-        this->icon().paint(&painter, this->rect());
+        this->icon().paint(&painter, 3, 3, 64, 64);
         break;
     }
 }
