@@ -3,7 +3,6 @@
 
 #include "abstractdialog.h"
 
-class Session;
 class WebView;
 class QProgressBar;
 class QGridLayout;
@@ -13,7 +12,7 @@ class YouTubeAuthDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit YouTubeAuthDialog(Session *session, const QString &accountName, QWidget *parent = 0);
+    explicit YouTubeAuthDialog(const QString &accountName, QWidget *parent = 0);
 
 private:
     inline void setLandscapeLayout() { this->setFixedHeight(340); }
@@ -23,7 +22,6 @@ private slots:
     void checkTitleForCode(const QString &title);
 
 private:
-    Session *m_session;
     QString m_name;
     WebView *m_webView;
     QProgressBar *m_progressBar;
